package api.test.rest.tsa.signer;

import api.test.core.BaseStepDefinitions;
import api.test.rest.RestGeneralStepDefinitions;
import api.test.rest.RestSessionContainer;
import core.*;
import cucumber.api.java.en.When;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class SignerStepDefinitions  extends BaseStepDefinitions {
    private static final Logger logger = LogManager.getLogger(RestGeneralStepDefinitions.class.getSimpleName());
    RestSessionContainer restSessionContainer;
    Request currentRequest;
    private String body;

    public SignerStepDefinitions(RestSessionContainer restSessionContainer, Request currentRequest, DataContainer dataContainer) {
        super(dataContainer);
        this.restSessionContainer = restSessionContainer;
        this.currentRequest = currentRequest;
    }

    @When("I get all keys via TSA Signer API")
    public void iGetAllKeysViaTSASignerAPI() {
        currentRequest.setPath("/v1/keys");
        Response response = RestClient.get(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }

    @When("^I get key \\{(.*)\\} via TSA Signer API$")
    public void iGetKeyViaTSASignerAPI(String key) {
        currentRequest.setPath("/v1/keys/" + key);
        Response response = RestClient.get(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }

    @When("I get issuer DID via TSA Signer API")
    public void iGetIssuerDIDViaTSASignerAPI() {
        currentRequest.setPath("/v1/issuerDID");
        Response response = RestClient.get(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }

    @When("I create presentation proof via TSA Signer API")
    public void iCreatePresentationProofViaTSASignerAPI() {
        currentRequest.setPath("/v1/presentation/proof");
        Response response = RestClient.post(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }

    @When("I create credential proof via TSA Signer API")
    public void iCreateCredentialProofViaTSASignerAPI() {
        currentRequest.setPath("/v1/credential/proof");
        Response response = RestClient.post(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }

    @When("I verify presentation proof via TSA Signer API")
    public void iVerifyPresentationProofViaTSASignerAPI() {
        currentRequest.setPath("/v1/presentation/verify");
        Response response = RestClient.post(currentRequest);
        addRequest(currentRequest);
        addResponse(response);
    }
}
